@@ -69,11 +69,12 @@ if __name__ == "__main__":
       parse_routing_response_history(message)
     elif topic == "/apollo/planning":
       parse_planning(message)
-    elif topic == "/apollo/sensor/camera/front_6mm/image":
+    elif topic == "/apollo/sensor/camera/traffic/image_long":
       parse_image(message)
-    elif topic == "/apollo/sensor/lidar32/compensator/PointCloud2":
-      parse_pointcloud(message)
-    else:
+    elif topic == "/apollo/sensor/velodyne64/compensator/PointCloud2":
+      # parse_pointcloud(message)
       pass
+    else:
+      print(message)
 
   f.close()
